@@ -7,6 +7,7 @@
  * Contract with IBM Corp.
  ****************************************************************************** */
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
 
 export default function createMockHttp() {
   const state = {
@@ -30,11 +31,17 @@ export default function createMockHttp() {
         { // cluster namespace
           metadata: {
             name: 'cluster1',
+            labels: {
+              'cluster.open-cluster-management.io/managedCluster': 'cluster1',
+            },
           },
         },
         { // cluster namespace
           metadata: {
             name: 'local-cluster',
+            labels: {
+              'cluster.open-cluster-management.io/managedCluster': 'local-cluster',
+            },
           },
         },
       ],
