@@ -7,6 +7,8 @@
  * Contract with IBM Corp.
  ****************************************************************************** */
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 import _ from 'lodash';
 import { gql } from 'apollo-server-express';
 import * as creation from './creation';
@@ -16,6 +18,7 @@ import * as namespace from './namespace';
 import * as policy from './policy';
 import * as genericResources from './generic-resources';
 import * as query from './query';
+import * as ansible from './ansible';
 
 const modules = [
   creation,
@@ -25,6 +28,7 @@ const modules = [
   policy,
   query,
   genericResources,
+  ansible,
 ];
 
 const mainDefs = [gql`
